@@ -10,14 +10,15 @@ def delay_call(method, *args, **kwargs):
 def get_url(name, *args, **kwargs):
     return reverse(name, kwargs=kwargs, args=args)
 
-def clean_dict(a):
+def clean_dict(a, tr=None):
     """Removes any keys where the values is None"""
     for key in a.keys():
         if a[key] is None:
             a.pop(key)
+        if tr:
+            a[key] = tr.get(str(a[key]), a[key])
     return a
 
-
 def cached(f):
     """We save the details per request"""
     key = '_' + f.__name__
